@@ -64,7 +64,7 @@ MANIFEST_PATH = "target/manifest.json"
 PROJECT_FILE = "dbt_project.yml"
 PROFILES_FILE = "profiles.yml"
 LOWER_DBT_V = "1.0.0"
-UPPER_DBT_V = "1.7.0"
+UPPER_DBT_V = "1.8.0"
 
 
 # https://github.com/dbt-labs/dbt-core/blob/c952d44ec5c2506995fbad75320acbae49125d3d/core/dbt/cli/resolvers.py#L6
@@ -376,8 +376,9 @@ class DbtParser:
 
             conn_info = {
                 "driver": conn_type,
-                "project": credentials.get("project"),
-                "dataset": credentials.get("dataset"),
+                "project": credentials.get("project") or credentials.get("database"),
+                "dataset": credentials.get("dataset") or credentials.get("schema"),
+                "impersonate_service_account": credentials.get("impersonate_service_account"),
             }
 
             self.threads = credentials.get("threads")
@@ -402,13 +403,13 @@ class DbtParser:
                 "user": credentials.get("user"),
                 "password": credentials.get("password") or credentials.get("pass"),
                 "port": credentials.get("port"),
-                "dbname": credentials.get("dbname"),
+                "dbname": credentials.get("dbname") or credentials.get("database"),
             }
             self.threads = credentials.get("threads")
         elif conn_type == "databricks":
             conn_info = {
                 "driver": conn_type,
-                "catalog": credentials.get("catalog"),
+                "catalog": credentials.get("catalog") or credentials.get("database"),
                 "server_hostname": credentials.get("host"),
                 "http_path": credentials.get("http_path"),
                 "schema": credentials.get("schema"),
@@ -420,7 +421,7 @@ class DbtParser:
                 "driver": "postgresql",
                 "host": credentials.get("host"),
                 "user": credentials.get("user"),
-                "password": credentials.get("password"),
+                "password": credentials.get("password") or credentials.get("pass"),
                 "port": credentials.get("port"),
                 "dbname": credentials.get("dbname") or credentials.get("database"),
             }
